Sensex ends flat; weaker Asian markets offset reform hopes | Reuters
Description: MUMBAI (Reuters) - The BSE Sensex and Nifty ended flat on Tuesday as weaker regional shares offset optimism over additional reforms a day after the government passed an executive order to ease land-acquisition
Keywords: Greece, Suresh Parmar

- Edition:
  IN
  - Africa
  - Arabic
  - Argentina
  - Brazil
  - Canada
  - China
  - France
  - Germany
  - Italy
  - Japan
  - Latin America
  - Mexico
  - Russia
  - Spain
  - United Kingdom
  - United States

- Article
- Comments (0)

# Sensex ends flat; weaker Asian markets offset reform hopes

MUMBAI Tue Dec 30, 2014 4:33pm IST

- Tweet
- Link this
- Share this
- MUMBAI (Reuters) - The BSE Sensex and Nifty ended flat on Tuesday as weaker regional shares offset optimism over additional reforms a day after the government passed an executive order to ease land-acquisition rules. Monday's announcement could...
- Email
- Print

People walk past the Bombay Stock Exchange (BSE) building in Mumbai May 13, 2014.

Credit: Reuters/Danish Siddiqui/Files

### Related Topics

- Business »

### Stocks

### India in 2014: Year in Review

## Bollywood 2014

The best and worst of Bollywood in 2014. Full Article

- A dream run for markets
- Year of leagues for sports
- Best photos of the year 2014
- Top pictures of the year: India
- Full coverage: India in 2014

MUMBAI (Reuters) - The BSE Sensex and Nifty ended flat on Tuesday as weaker regional shares offset optimism over additional reforms a day after the government passed an executive order to ease land-acquisition rules.

Monday's announcement could kick-start hundreds of billions of dollars worth of stalled projects, and comes after separate orders were passed to implement coal and insurance reforms.

However, weak sentiment across the region on a sharp selloff in commodities overnight and political uncertainty in Greece left investors hesitant to take big bets.

The BSE Sensex gained 0.03 percent at 27,403.54 points, while the broader Nifty ended 0.02 higher percent at 8,248.25 points.

Infrastructure stocks gained with Larsen and Toubro (LART.NS) adding 0.5 percent while Lanco Infratech (LAIN.NS) rose 4.3 percent.

However, energy firms fell as Brent crude fell to a 5-1/2 year low below $57 a barrel. Reliance Industries (RELI.NS) closed down 1.9 percent and Oil and Natural Gas Corp (ONGC.NS) ended down 1.5 percent.

(Reporting by Indulal PM; Editing by Sunil Nair)

FILED UNDER:
Business

- Tweet this
- Link this
- Share this
- Digg this
- Email
- Print
- Reprints

### Trending On Reuters

### Banking

## India needs reforms in banking sector, more autonomy for state banks: Jaitley

India needs to "conceive" several reforms in the banking sector, Finance Minister Arun Jaitley told reporters on the sidelines of a two-day banking retreat. Full Article

- India prepares reform plan for ailing state banks

### Follow Reuters

- Facebook
- Twitter
- RSS
- YouTube

### REUTERS SHOWCASE

## Factory Activity

Weak factory reports from Asia, Europe suggest more central bank action Full Article

## AirAsia Jet Crash

Search teams battle rough weather in hunt for AirAsia wreck Full Article

## Banking Sector

India prepares reform roadmap for ailing state banks Full Article

## Solar Energy

Govt raises solar investment target to $100 bln by 2022 Full Article

## India Factory Growth

Dec factory growth at 2-year high as orders surge - PMI Full Article

## Tata Steel Mine

Tata Steel resumes operations at top iron ore mine - spokesman Full Article

## U.S. Economy

U.S. factory sector suffers end-of-year chill Full Article

## Trip Tips

A glimpse of little Tibet in southern India Full Article

## India in 2014

A review of the top stories from India Full Coverage

## Reuters India Mobile

Get the latest news on the go. Visit Reuters India on your mobile device Full Coverage

- Edition:
  IN
  - Arabic
  - Argentina
  - Brazil
  - Canada
  - China
  - France
  - Germany
  - Italy
  - Japan
  - Latin America
  - Mexico
  - Russia
  - Spain
  - United Kingdom
  - United States

Back to top

Reuters.com

- Business
- Markets
- India
- Technology
- Opinion
- Money
- Pictures
- Videos
- Site Index
- Mobile

More from Reuters

- Reuters News Agency
- Brand Attribution Guidelines
- Delivery Options

Support & Contact

- Support
- Corrections

Connect with Reuters

- Twitter
- Facebook
- LinkedIn
- RSS
- Newsletters

About

- Privacy Policy
- Terms of Use
- AdChoices
- Copyright

Our Flagship financial information platform incorporating Reuters Insider
An ultra-low latency infrastructure for electronic trading and data distribution
A connected approach to governance, risk and compliance
Our next generation legal research platform
Our global tax workstation

- Thomsonreuters.com
- About Thomson Reuters
- Investor Relations
- Careers
- Contact Us

Thomson Reuters is the world's largest international multimedia news agency, providing investing news, world news, business news, technology news, headline news, small business news, news alerts, personal finance, stock market, and mutual funds information available on Reuters.com, video, mobile, and interactive television platforms. Thomson Reuters journalists are subject to an Editorial Handbook which requires fair presentation and disclosure of relevant interests.

NYSE and AMEX quotes delayed by at least 20 minutes. Nasdaq delayed by at least 15 minutes. For a complete list of exchanges and delays, please click here.